# tpdk
Our API suite for the **Resolution Center** and the **Safe Checkout** features.
Simple, yet elegant web interfaces for your convenience. One request away from your first automated resolution or safe-checkout.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.204
- Package version: 2.0.204
- Generator version: 7.6.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://tripartie.com](https://tripartie.com)

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/tripartie/tpdk.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/tripartie/tpdk.git`)

Then import the package:
```python
import tpdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import tpdk
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import tpdk
from tpdk.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://staging-api.tripartie.com
# See configuration.py for a list of all supported configuration parameters.
configuration = tpdk.Configuration(
    host = "https://staging-api.tripartie.com"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: jwtPersonalKey
configuration.api_key['jwtPersonalKey'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['jwtPersonalKey'] = 'Bearer'


# Enter a context with an instance of the API client
with tpdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = tpdk.BrandingApi(api_client)
    id = 'id_example' # str | Organization identifier
    organization_update = tpdk.OrganizationUpdate() # OrganizationUpdate | The updated Organization resource

    try:
        # Update your Organization details, branding or parameters
        api_response = api_instance.api_organizations_id_patch(id, organization_update)
        print("The response of BrandingApi->api_organizations_id_patch:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling BrandingApi->api_organizations_id_patch: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://staging-api.tripartie.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BrandingApi* | [**api_organizations_id_patch**](docs/BrandingApi.md#api_organizations_id_patch) | **PATCH** /organizations/{id} | Update your Organization details, branding or parameters
*BrandingApi* | [**api_organizations_idicon_delete**](docs/BrandingApi.md#api_organizations_idicon_delete) | **DELETE** /organizations/{id}/icon | Unset your Organization Icon
*BrandingApi* | [**api_organizations_idicon_post**](docs/BrandingApi.md#api_organizations_idicon_post) | **POST** /organizations/{id}/icon | Upload your Organization Icon
*BrandingApi* | [**api_organizations_idlogo_delete**](docs/BrandingApi.md#api_organizations_idlogo_delete) | **DELETE** /organizations/{id}/logo | Unset your Organization Logo
*BrandingApi* | [**api_organizations_idlogo_post**](docs/BrandingApi.md#api_organizations_idlogo_post) | **POST** /organizations/{id}/logo | Upload your Organization logo
*NotificationApi* | [**api_personas_idnotifications_get_collection**](docs/NotificationApi.md#api_personas_idnotifications_get_collection) | **GET** /personas/{id}/notifications | Retrieve pending notifications for Persona
*NotificationApi* | [**api_personas_persona_idnotifications_id_patch**](docs/NotificationApi.md#api_personas_persona_idnotifications_id_patch) | **PATCH** /personas/{personaId}/notifications/{id} | Mark as read/unread a notification for Persona
*NotificationApi* | [**api_users_idnotifications_get_collection**](docs/NotificationApi.md#api_users_idnotifications_get_collection) | **GET** /users/{id}/notifications | Retrieves the collection of Notification resources.
*NotificationApi* | [**api_users_user_idnotifications_id_patch**](docs/NotificationApi.md#api_users_user_idnotifications_id_patch) | **PATCH** /users/{userId}/notifications/{id} | Mark as read/unread a notification for User
*OrganizationApi* | [**api_organizations_get_collection**](docs/OrganizationApi.md#api_organizations_get_collection) | **GET** /organizations | Retrieves the collection of Organization resources.
*OrganizationApi* | [**api_organizations_id_get**](docs/OrganizationApi.md#api_organizations_id_get) | **GET** /organizations/{id} | Retrieves a Organization resource.
*PersonaApi* | [**api_personas_get_collection**](docs/PersonaApi.md#api_personas_get_collection) | **GET** /personas | Retrieves the collection of Persona resources.
*PersonaApi* | [**api_personas_id_delete**](docs/PersonaApi.md#api_personas_id_delete) | **DELETE** /personas/{id} | Unregister a Persona (Your customer)
*PersonaApi* | [**api_personas_id_get**](docs/PersonaApi.md#api_personas_id_get) | **GET** /personas/{id} | Retrieves a Persona resource.
*PersonaApi* | [**api_personas_id_patch**](docs/PersonaApi.md#api_personas_id_patch) | **PATCH** /personas/{id} | Updates the Persona resource.
*PersonaApi* | [**api_personas_idtoken_post**](docs/PersonaApi.md#api_personas_idtoken_post) | **POST** /personas/{id}/token | Issue authenticated URL for single end-user
*PersonaApi* | [**api_personas_post**](docs/PersonaApi.md#api_personas_post) | **POST** /personas | Register a Persona (Your customer)
*ResolutionCenterApi* | [**api_disputes_get_collection**](docs/ResolutionCenterApi.md#api_disputes_get_collection) | **GET** /disputes | Retrieves the collection of Dispute resources.
*ResolutionCenterApi* | [**api_disputes_post**](docs/ResolutionCenterApi.md#api_disputes_post) | **POST** /disputes | Draft a standalone Dispute
*ResolutionCenterApi* | [**api_disputes_ulid_delete**](docs/ResolutionCenterApi.md#api_disputes_ulid_delete) | **DELETE** /disputes/{ulid} | Abandon claims on Dispute
*ResolutionCenterApi* | [**api_disputes_ulid_get**](docs/ResolutionCenterApi.md#api_disputes_ulid_get) | **GET** /disputes/{ulid} | Retrieves a Dispute resource.
*ResolutionCenterApi* | [**api_disputes_ulid_patch**](docs/ResolutionCenterApi.md#api_disputes_ulid_patch) | **PATCH** /disputes/{ulid} | Update the Dispute
*ResolutionCenterApi* | [**api_disputes_ulidevaluations_post**](docs/ResolutionCenterApi.md#api_disputes_ulidevaluations_post) | **POST** /disputes/{ulid}/evaluations | Submit an Evaluation for the Dispute
*ResolutionCenterApi* | [**api_disputes_ulidevidences_get_collection**](docs/ResolutionCenterApi.md#api_disputes_ulidevidences_get_collection) | **GET** /disputes/{ulid}/evidences | Retrieve all Evidences in Dispute
*ResolutionCenterApi* | [**api_disputes_ulidevidences_id_delete**](docs/ResolutionCenterApi.md#api_disputes_ulidevidences_id_delete) | **DELETE** /disputes/{ulid}/evidences/{id} | Withdraw an Evidence from a Dispute
*ResolutionCenterApi* | [**api_disputes_ulidevidences_idmedia_post**](docs/ResolutionCenterApi.md#api_disputes_ulidevidences_idmedia_post) | **POST** /disputes/{ulid}/evidences/{id}/media | Upload attachment in regard of described Evidence
*ResolutionCenterApi* | [**api_disputes_ulidevidences_post**](docs/ResolutionCenterApi.md#api_disputes_ulidevidences_post) | **POST** /disputes/{ulid}/evidences | Submit an Evidence to the Dispute case
*ResolutionCenterApi* | [**api_disputes_ulidparcels_get_collection**](docs/ResolutionCenterApi.md#api_disputes_ulidparcels_get_collection) | **GET** /disputes/{ulid}/parcels | Retrieves the collection of Parcel resources.
*ResolutionCenterApi* | [**api_disputes_ulidparcels_id_delete**](docs/ResolutionCenterApi.md#api_disputes_ulidparcels_id_delete) | **DELETE** /disputes/{ulid}/parcels/{id} | Removes the Parcel resource.
*ResolutionCenterApi* | [**api_disputes_ulidparcels_post**](docs/ResolutionCenterApi.md#api_disputes_ulidparcels_post) | **POST** /disputes/{ulid}/parcels | Creates a Parcel resource.
*ResolutionCenterApi* | [**api_offers_ulidmedias_id_delete**](docs/ResolutionCenterApi.md#api_offers_ulidmedias_id_delete) | **DELETE** /offers/{ulid}/medias/{id} | Removes the Media resource.
*ResolutionCenterApi* | [**api_offers_ulidmedias_post**](docs/ResolutionCenterApi.md#api_offers_ulidmedias_post) | **POST** /offers/{ulid}/medias | Upload a picture for a given Offer
*UserApi* | [**api_api_clients_get_collection**](docs/UserApi.md#api_api_clients_get_collection) | **GET** /api-clients | Retrieves the collection of ApiClient resources.
*UserApi* | [**api_api_clients_identifier_delete**](docs/UserApi.md#api_api_clients_identifier_delete) | **DELETE** /api-clients/{identifier} | Removes the ApiClient resource.
*UserApi* | [**api_api_clients_identifier_get**](docs/UserApi.md#api_api_clients_identifier_get) | **GET** /api-clients/{identifier} | Retrieves a ApiClient resource.
*UserApi* | [**api_api_clients_post**](docs/UserApi.md#api_api_clients_post) | **POST** /api-clients | Creates a ApiClient resource.
*UserApi* | [**api_invite_post**](docs/UserApi.md#api_invite_post) | **POST** /invite | Organization invite
*UserApi* | [**api_me_get**](docs/UserApi.md#api_me_get) | **GET** /me | Retrieves a User resource.
*UserApi* | [**api_personasauthentication_post**](docs/UserApi.md#api_personasauthentication_post) | **POST** /personas/authentication | Persona Authentication
*UserApi* | [**api_personasme_get**](docs/UserApi.md#api_personasme_get) | **GET** /personas/me | Retrieve your authenticated Persona
*UserApi* | [**api_personasregister_post**](docs/UserApi.md#api_personasregister_post) | **POST** /personas/register | Persona external registration
*UserApi* | [**api_register_post**](docs/UserApi.md#api_register_post) | **POST** /register | Organization onboarding
*UserApi* | [**api_users_get_collection**](docs/UserApi.md#api_users_get_collection) | **GET** /users | Retrieves the collection of User resources.
*UserApi* | [**api_users_id_delete**](docs/UserApi.md#api_users_id_delete) | **DELETE** /users/{id} | Removes the User resource.
*UserApi* | [**api_users_id_get**](docs/UserApi.md#api_users_id_get) | **GET** /users/{id} | Retrieves a User resource.
*UserApi* | [**api_users_id_patch**](docs/UserApi.md#api_users_id_patch) | **PATCH** /users/{id} | Updates the User resource.
*UserApi* | [**api_users_idavatar_delete**](docs/UserApi.md#api_users_idavatar_delete) | **DELETE** /users/{id}/avatar | Unset your personal avatar
*UserApi* | [**api_users_idavatar_post**](docs/UserApi.md#api_users_idavatar_post) | **POST** /users/{id}/avatar | Upload your personal avatar
*UserApi* | [**api_users_idemail_patch**](docs/UserApi.md#api_users_idemail_patch) | **PATCH** /users/{id}/email | Update user email
*UserApi* | [**api_users_idemail_validation_patch**](docs/UserApi.md#api_users_idemail_validation_patch) | **PATCH** /users/{id}/email-validation | Validate email ownership
*UserApi* | [**api_users_idenable_patch**](docs/UserApi.md#api_users_idenable_patch) | **PATCH** /users/{id}/enable | Updates the User resource.
*UserApi* | [**api_users_idpassword_patch**](docs/UserApi.md#api_users_idpassword_patch) | **PATCH** /users/{id}/password | Updates the User resource.
*UserApi* | [**api_users_idtotp_setup_patch**](docs/UserApi.md#api_users_idtotp_setup_patch) | **PATCH** /users/{id}/totp-setup | Updates the User resource.
*UserApi* | [**api_users_idtotp_toggle_patch**](docs/UserApi.md#api_users_idtotp_toggle_patch) | **PATCH** /users/{id}/totp-toggle | Updates the User resource.
*UserApi* | [**authentication_post**](docs/UserApi.md#authentication_post) | **POST** /authentication | User authentication
*WebhookApi* | [**api_webhook_histories_get_collection**](docs/WebhookApi.md#api_webhook_histories_get_collection) | **GET** /webhook-histories | Retrieves the collection of WebhookHistory resources.
*WebhookApi* | [**api_webhook_histories_id_get**](docs/WebhookApi.md#api_webhook_histories_id_get) | **GET** /webhook-histories/{id} | Retrieves a WebhookHistory resource.
*WebhookApi* | [**api_webhook_histories_id_put**](docs/WebhookApi.md#api_webhook_histories_id_put) | **PUT** /webhook-histories/{id} | Replay a Webhook that ended up in failure
*WebhookApi* | [**api_webhook_subscriptions_get_collection**](docs/WebhookApi.md#api_webhook_subscriptions_get_collection) | **GET** /webhook-subscriptions | Retrieves the collection of WebhookSubscription resources.
*WebhookApi* | [**api_webhook_subscriptions_id_delete**](docs/WebhookApi.md#api_webhook_subscriptions_id_delete) | **DELETE** /webhook-subscriptions/{id} | Removes the WebhookSubscription resource.
*WebhookApi* | [**api_webhook_subscriptions_post**](docs/WebhookApi.md#api_webhook_subscriptions_post) | **POST** /webhook-subscriptions | Subscribe to Event(s)


## Documentation For Models

 - [AccessError](docs/AccessError.md)
 - [Address](docs/Address.md)
 - [ApiClientPostCreationRead](docs/ApiClientPostCreationRead.md)
 - [ApiClientRead](docs/ApiClientRead.md)
 - [ApiClientWrite](docs/ApiClientWrite.md)
 - [AuthError](docs/AuthError.md)
 - [DisputeAddressIndependentWrite](docs/DisputeAddressIndependentWrite.md)
 - [DisputeCollectionRead](docs/DisputeCollectionRead.md)
 - [DisputeDisputeRead](docs/DisputeDisputeRead.md)
 - [DisputeIndependentWrite](docs/DisputeIndependentWrite.md)
 - [DisputeMediaRead](docs/DisputeMediaRead.md)
 - [DisputeMetadataIndependentWrite](docs/DisputeMetadataIndependentWrite.md)
 - [DisputeMetadataRead](docs/DisputeMetadataRead.md)
 - [DisputeOfferCollectionRead](docs/DisputeOfferCollectionRead.md)
 - [DisputeOfferIndependentWrite](docs/DisputeOfferIndependentWrite.md)
 - [DisputeOfferRead](docs/DisputeOfferRead.md)
 - [DisputeOrganizationRead](docs/DisputeOrganizationRead.md)
 - [DisputeParcelIndependentWrite](docs/DisputeParcelIndependentWrite.md)
 - [DisputeParcelRead](docs/DisputeParcelRead.md)
 - [DisputePersonaCollectionRead](docs/DisputePersonaCollectionRead.md)
 - [DisputePersonaIndependentWrite](docs/DisputePersonaIndependentWrite.md)
 - [DisputePersonaRead](docs/DisputePersonaRead.md)
 - [DisputePostCreationRead](docs/DisputePostCreationRead.md)
 - [DisputeRead](docs/DisputeRead.md)
 - [DisputeTransactionCollectionRead](docs/DisputeTransactionCollectionRead.md)
 - [DisputeTransactionIndependentWrite](docs/DisputeTransactionIndependentWrite.md)
 - [DisputeTransactionRead](docs/DisputeTransactionRead.md)
 - [DisputeUpdate](docs/DisputeUpdate.md)
 - [DisputeViewRead](docs/DisputeViewRead.md)
 - [DisputeWorkflowEventRead](docs/DisputeWorkflowEventRead.md)
 - [EvaluationRead](docs/EvaluationRead.md)
 - [EvaluationWrite](docs/EvaluationWrite.md)
 - [Evidence](docs/Evidence.md)
 - [EvidenceMediaRead](docs/EvidenceMediaRead.md)
 - [EvidenceRead](docs/EvidenceRead.md)
 - [EvidenceWrite](docs/EvidenceWrite.md)
 - [GenericError](docs/GenericError.md)
 - [InvalidQueryError](docs/InvalidQueryError.md)
 - [Media](docs/Media.md)
 - [MediaDisputeRead](docs/MediaDisputeRead.md)
 - [MediaRead](docs/MediaRead.md)
 - [MediaUserRead](docs/MediaUserRead.md)
 - [MessageError](docs/MessageError.md)
 - [Metadata](docs/Metadata.md)
 - [MetadataDisputeRead](docs/MetadataDisputeRead.md)
 - [NotFoundError](docs/NotFoundError.md)
 - [NotificationRead](docs/NotificationRead.md)
 - [NotificationUpdate](docs/NotificationUpdate.md)
 - [OfferDisputeRead](docs/OfferDisputeRead.md)
 - [OrganizationAddressUpdate](docs/OrganizationAddressUpdate.md)
 - [OrganizationCollectionRead](docs/OrganizationCollectionRead.md)
 - [OrganizationDisputeRead](docs/OrganizationDisputeRead.md)
 - [OrganizationMediaCollectionRead](docs/OrganizationMediaCollectionRead.md)
 - [OrganizationMediaRead](docs/OrganizationMediaRead.md)
 - [OrganizationRead](docs/OrganizationRead.md)
 - [OrganizationUpdate](docs/OrganizationUpdate.md)
 - [OrganizationUserRead](docs/OrganizationUserRead.md)
 - [Parcel](docs/Parcel.md)
 - [ParcelDisputeRead](docs/ParcelDisputeRead.md)
 - [ParcelWrite](docs/ParcelWrite.md)
 - [Persona](docs/Persona.md)
 - [PersonaAddressRead](docs/PersonaAddressRead.md)
 - [PersonaAddressUpdate](docs/PersonaAddressUpdate.md)
 - [PersonaAddressWrite](docs/PersonaAddressWrite.md)
 - [PersonaAuthReturn](docs/PersonaAuthReturn.md)
 - [PersonaCollectionRead](docs/PersonaCollectionRead.md)
 - [PersonaDisputeRead](docs/PersonaDisputeRead.md)
 - [PersonaExternalAuth](docs/PersonaExternalAuth.md)
 - [PersonaMetadataRead](docs/PersonaMetadataRead.md)
 - [PersonaMetadataUpdate](docs/PersonaMetadataUpdate.md)
 - [PersonaMetadataWrite](docs/PersonaMetadataWrite.md)
 - [PersonaPostAuthRead](docs/PersonaPostAuthRead.md)
 - [PersonaRead](docs/PersonaRead.md)
 - [PersonaRegister](docs/PersonaRegister.md)
 - [PersonaTokenWrite](docs/PersonaTokenWrite.md)
 - [PersonaUpdate](docs/PersonaUpdate.md)
 - [PersonaWrite](docs/PersonaWrite.md)
 - [RateLimitError](docs/RateLimitError.md)
 - [TransactionDisputeRead](docs/TransactionDisputeRead.md)
 - [UnprocessableEntity](docs/UnprocessableEntity.md)
 - [UnprocessableEntityViolationsInner](docs/UnprocessableEntityViolationsInner.md)
 - [User](docs/User.md)
 - [UserAddressWrite](docs/UserAddressWrite.md)
 - [UserAuthenticatedRead](docs/UserAuthenticatedRead.md)
 - [UserCollectionRead](docs/UserCollectionRead.md)
 - [UserEmailValidationWrite](docs/UserEmailValidationWrite.md)
 - [UserInvite](docs/UserInvite.md)
 - [UserJwtCreated](docs/UserJwtCreated.md)
 - [UserJwtWrite](docs/UserJwtWrite.md)
 - [UserMediaAuthenticatedRead](docs/UserMediaAuthenticatedRead.md)
 - [UserMediaCollectionRead](docs/UserMediaCollectionRead.md)
 - [UserMediaRead](docs/UserMediaRead.md)
 - [UserOrganizationAuthenticatedRead](docs/UserOrganizationAuthenticatedRead.md)
 - [UserOrganizationCollectionRead](docs/UserOrganizationCollectionRead.md)
 - [UserOrganizationRead](docs/UserOrganizationRead.md)
 - [UserOrganizationWrite](docs/UserOrganizationWrite.md)
 - [UserPostRegisterRead](docs/UserPostRegisterRead.md)
 - [UserTotpSetupRead](docs/UserTotpSetupRead.md)
 - [UserTotpToggleWrite](docs/UserTotpToggleWrite.md)
 - [UserUpdate](docs/UserUpdate.md)
 - [UserUserEmailUpdate](docs/UserUserEmailUpdate.md)
 - [UserUserPasswordUpdate](docs/UserUserPasswordUpdate.md)
 - [UserUserRead](docs/UserUserRead.md)
 - [UserUserSubscribed](docs/UserUserSubscribed.md)
 - [UserWrite](docs/UserWrite.md)
 - [View](docs/View.md)
 - [ViewDisputeRead](docs/ViewDisputeRead.md)
 - [Webhook](docs/Webhook.md)
 - [WebhookHistoryCollectionRead](docs/WebhookHistoryCollectionRead.md)
 - [WebhookHistoryRead](docs/WebhookHistoryRead.md)
 - [WebhookObject](docs/WebhookObject.md)
 - [WebhookSubscriptionRead](docs/WebhookSubscriptionRead.md)
 - [WebhookSubscriptionWrite](docs/WebhookSubscriptionWrite.md)
 - [WorkflowEventDisputeRead](docs/WorkflowEventDisputeRead.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="oauth"></a>
### oauth

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - **OFFER_READ**: Read-only operations on safe-checkout offers
 - **OFFER_WRITE**: Write permissions on safe-checkout offers
 - **DISPUTE_READ**: Read-only operations on disputes
 - **DISPUTE_WRITE**: Write permissions on disputes
 - **DISPUTE_ARBITRATION**: Update permission on disputes for manual arbitration only
 - **ORGANIZATION_READ**: Read organization details and stats
 - **RULING_READ**: Read custom rules applied to the dispute resolution program
 - **RULING_WRITE**: Write custom rules applied to the dispute resolution program
 - **PERSONA_READ**: Read operations on the shared user-base knowledge
 - **PERSONA_WRITE**: Write permissions on the shared user-base knowledge
 - **PERSONA_AUTH**: Capability to issue short-term lived authenticated URL
 - **INTERNAL_WRITE**: Special internal scope

<a id="jwtPersonalKey"></a>
### jwtPersonalKey

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

<a id="personaAuthKey"></a>
### personaAuthKey

- **Type**: API key
- **API key parameter name**: X-Persona-Authorization
- **Location**: HTTP header


## Author

noc@tripartie.com


